pub fn parse_event_contract_instrument(
definition: &OKXInstrument,
margin_init: Option<Decimal>,
margin_maint: Option<Decimal>,
maker_fee: Option<Decimal>,
taker_fee: Option<Decimal>,
ts_init: UnixNanos,
) -> Result<InstrumentAny>Expand description
Parses an OKX event contract instrument definition into a Nautilus binary option.
Errors
Returns an error if the instrument definition cannot be parsed.